summaryrefslogtreecommitdiffhomepage
path: root/Private/Source/FileManager.cxx
diff options
context:
space:
mode:
Diffstat (limited to 'Private/Source/FileManager.cxx')
-rw-r--r--Private/Source/FileManager.cxx6
1 files changed, 3 insertions, 3 deletions
diff --git a/Private/Source/FileManager.cxx b/Private/Source/FileManager.cxx
index 4d3c9417..bbe7d30b 100644
--- a/Private/Source/FileManager.cxx
+++ b/Private/Source/FileManager.cxx
@@ -9,9 +9,9 @@
#include <NewKit/Utils.hpp>
/// BUGS: 0
-//! @brief File manager for HCore.
+//! @brief File manager for NewOS.
-namespace HCore {
+namespace NewOS {
static FilesystemManagerInterface* kMounted = nullptr;
/// @brief FilesystemManager getter.
@@ -42,4 +42,4 @@ bool FilesystemManagerInterface::Mount(FilesystemManagerInterface* mountPtr) {
return false;
}
-} // namespace HCore
+} // namespace NewOS